@@ -14,7 +14,7 @@
 int main(int argc, char* argv[]) {
     if (argc != 3) {
         std::cerr << "Usage: " << argv[0] << " INPUT-FILE OUTPUT-FILE\n";
-        std::exit(1);
+        return 1;
     }
 
     try {
@@ -34,7 +34,9 @@ int main(int argc, char* argv[]) {
         reader.close();
     } catch (const std::exception& e) {
         std::cerr << e.what() << '\n';
-        std::exit(1);
+        return 1;
     }
+
+    return 0;
 }
 
