@@ -1,14 +1,15 @@
 #include "catch.hpp"
 
-#include <iterator>
-
 #include <osmium/io/file.hpp>
 
+#include <iterator>
+#include <stdexcept>
+
 TEST_CASE("Default file format") {
     const osmium::io::File f;
     REQUIRE(osmium::io::file_format::unknown == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     REQUIRE_THROWS_AS(f.check(), const std::runtime_error&);
 }
 
@@ -16,7 +17,7 @@ TEST_CASE("File format when empty (stdin/stdout)") {
     const osmium::io::File f{""};
     REQUIRE(osmium::io::file_format::unknown == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     REQUIRE_THROWS_AS(f.check(), const std::runtime_error&);
 }
 
@@ -24,16 +25,16 @@ TEST_CASE("File format from dash (stdin/stdout)") {
     const osmium::io::File f{"-"};
     REQUIRE(osmium::io::file_format::unknown == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     REQUIRE_THROWS_AS(f.check(), const std::runtime_error&);
 }
 
 TEST_CASE("File format from dash with osm.bz2") {
     const osmium::io::File f{"-", "osm.bz2"};
-    REQUIRE("" == f.filename());
+    REQUIRE(f.filename().empty());
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::bzip2 == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -41,7 +42,7 @@ TEST_CASE("Detect file format by suffix 'osm'") {
     const osmium::io::File f{"test.osm"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -49,7 +50,7 @@ TEST_CASE("Detect file format by suffix 'pbf'") {
     const osmium::io::File f{"test.pbf"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -57,7 +58,7 @@ TEST_CASE("Detect file format by suffix 'osm.pbf'") {
     const osmium::io::File f{"test.osm.pbf"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -65,7 +66,7 @@ TEST_CASE("Detect file format by suffix 'opl'") {
     const osmium::io::File f{"test.opl"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -73,7 +74,7 @@ TEST_CASE("Detect file format by suffix 'osm.opl'") {
     const osmium::io::File f{"test.osm.opl"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -81,7 +82,7 @@ TEST_CASE("Detect file format by suffix 'osm.gz'") {
     const osmium::io::File f{"test.osm.gz"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::gzip == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -89,7 +90,7 @@ TEST_CASE("Detect file format by suffix 'opl.bz2'") {
     const osmium::io::File f{"test.osm.opl.bz2"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::bzip2 == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -97,7 +98,7 @@ TEST_CASE("Detect file format by suffix 'osc.gz'") {
     const osmium::io::File f{"test.osc.gz"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::gzip == f.compression());
-    REQUIRE(true == f.has_multiple_object_versions());
+    REQUIRE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -105,7 +106,7 @@ TEST_CASE("Detect file format by suffix 'opl.gz'") {
     const osmium::io::File f{"test.osh.opl.gz"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::gzip == f.compression());
-    REQUIRE(true == f.has_multiple_object_versions());
+    REQUIRE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -113,7 +114,7 @@ TEST_CASE("Detect file format by suffix 'osh.pbf'") {
     const osmium::io::File f{"test.osh.pbf"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(true == f.has_multiple_object_versions());
+    REQUIRE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -121,7 +122,7 @@ TEST_CASE("Override file format by suffix 'osm'") {
     const osmium::io::File f{"test", "osm"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -129,7 +130,7 @@ TEST_CASE("Override file format by suffix 'pbf'") {
     const osmium::io::File f{"test", "pbf"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -137,7 +138,7 @@ TEST_CASE("Override file format by suffix 'osm.pbf'") {
     const osmium::io::File f{"test", "osm.pbf"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -145,7 +146,7 @@ TEST_CASE("Override file format by suffix 'opl'") {
     const osmium::io::File f{"test", "opl"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -153,7 +154,7 @@ TEST_CASE("Override file format by suffix 'osm.opl'") {
     const osmium::io::File f{"test", "osm.opl"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -161,7 +162,7 @@ TEST_CASE("Override file format by suffix 'osm.gz'") {
     const osmium::io::File f{"test", "osm.gz"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::gzip == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -169,7 +170,7 @@ TEST_CASE("Override file format by suffix 'osm.opl.bz2'") {
     const osmium::io::File f{"test", "osm.opl.bz2"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::bzip2 == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -177,7 +178,7 @@ TEST_CASE("Override file format by suffix 'osc.gz'") {
     const osmium::io::File f{"test", "osc.gz"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::gzip == f.compression());
-    REQUIRE(true == f.has_multiple_object_versions());
+    REQUIRE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -185,7 +186,7 @@ TEST_CASE("Override file format by suffix 'osh.opl.gz'") {
     const osmium::io::File f{"test", "osh.opl.gz"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::gzip == f.compression());
-    REQUIRE(true == f.has_multiple_object_versions());
+    REQUIRE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -193,7 +194,7 @@ TEST_CASE("File format by suffix 'blackhole'") {
     const osmium::io::File f{"test.blackhole"};
     REQUIRE(osmium::io::file_format::blackhole == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -201,7 +202,7 @@ TEST_CASE("Override file format by suffix 'blackhole'") {
     const osmium::io::File f{"test", "blackhole"};
     REQUIRE(osmium::io::file_format::blackhole == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -209,7 +210,7 @@ TEST_CASE("Override file format by suffix 'osm.blackhole'") {
     const osmium::io::File f{"test", "osm.blackhole"};
     REQUIRE(osmium::io::file_format::blackhole == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -217,7 +218,7 @@ TEST_CASE("Override file format by suffix 'osm.blackhole.bz2'") {
     const osmium::io::File f{"test", "osm.blackhole.bz2"};
     REQUIRE(osmium::io::file_format::blackhole == f.format());
     REQUIRE(osmium::io::file_compression::bzip2 == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -225,7 +226,7 @@ TEST_CASE("Override file format by suffix 'osh.blackhole.gz'") {
     const osmium::io::File f{"test", "osh.blackhole.gz"};
     REQUIRE(osmium::io::file_format::blackhole == f.format());
     REQUIRE(osmium::io::file_compression::gzip == f.compression());
-    REQUIRE(true == f.has_multiple_object_versions());
+    REQUIRE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -233,7 +234,7 @@ TEST_CASE("Override file format by suffix 'osh.pbf'") {
     const osmium::io::File f{"test", "osh.pbf"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(true == f.has_multiple_object_versions());
+    REQUIRE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -241,7 +242,7 @@ TEST_CASE("Format option pbf history") {
     const osmium::io::File f{"test", "pbf,history=true"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(true == f.has_multiple_object_versions());
+    REQUIRE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -289,15 +290,15 @@ TEST_CASE("URL without format") {
     const osmium::io::File f{"http://www.example.com/api"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
 TEST_CASE("URL without format and filename") {
-    const osmium::io::File f{"http://planet.osm.org/pbf/planet-latest.osm.pbf"};
+    const osmium::io::File f{"https://planet.osm.org/pbf/planet-latest.osm.pbf"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(false == f.has_multiple_object_versions());
+    REQUIRE_FALSE(f.has_multiple_object_versions());
     f.check();
 }
 
@@ -305,7 +306,7 @@ TEST_CASE("URL with format") {
     const osmium::io::File f{"http://www.example.com/api", "osh"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE(true == f.has_multiple_object_versions());
+    REQUIRE(f.has_multiple_object_versions());
     f.check();
 }
 
