@@ -1,22 +1,25 @@
 #include "catch.hpp"
 
-#include <sstream>
-#include <string>
-#include <vector>
-
 #include <osmium/osm/timestamp.hpp>
 
+#include <sstream>
+#include <stdexcept>
+#include <string>
+#include <vector>
+
 TEST_CASE("Timestamp can be default initialized to invalid value") {
-    const osmium::Timestamp t;
+    const osmium::Timestamp t{};
     REQUIRE(0 == uint32_t(t));
-    REQUIRE("" == t.to_iso());
+    REQUIRE(t.to_iso().empty());
+    REQUIRE(t.to_iso_all() == "1970-01-01T00:00:00Z");
     REQUIRE_FALSE(t.valid());
 }
 
 TEST_CASE("Timestamp invalid value is zero") {
     const osmium::Timestamp t{static_cast<time_t>(0)};
     REQUIRE(0 == uint32_t(t));
-    REQUIRE("" == t.to_iso());
+    REQUIRE(t.to_iso().empty());
+    REQUIRE(t.to_iso_all() == "1970-01-01T00:00:00Z");
     REQUIRE_FALSE(t.valid());
 }
 
@@ -74,8 +77,39 @@ TEST_CASE("Timestamp can be written to stream") {
     REQUIRE("1970-01-01T00:00:01Z" == ss.str());
 }
 
-TEST_CASE("Valid timestamps") {
+void test_int2_to_string(int value, const char* ref) {
+    std::string s;
+    osmium::detail::add_2digit_int_to_string(value, s);
+    REQUIRE(s == ref);
+}
 
+void test_int4_to_string(int value, const char* ref) {
+    std::string s;
+    osmium::detail::add_4digit_int_to_string(value, s);
+    REQUIRE(s == ref);
+}
+
+TEST_CASE("Write two digit numbers") {
+    test_int2_to_string( 0, "00");
+    test_int2_to_string( 1, "01");
+    test_int2_to_string( 2, "02");
+    test_int2_to_string( 3, "03");
+    test_int2_to_string( 4, "04");
+    test_int2_to_string( 9, "09");
+    test_int2_to_string(10, "10");
+    test_int2_to_string(20, "20");
+    test_int2_to_string(29, "29");
+    test_int2_to_string(99, "99");
+}
+
+TEST_CASE("Write four digit numbers") {
+    test_int4_to_string(1000, "1000");
+    test_int4_to_string(1001, "1001");
+    test_int4_to_string(2018, "2018");
+    test_int4_to_string(9999, "9999");
+}
+
+TEST_CASE("Valid timestamps") {
     std::vector<std::string> test_cases = {
         "1970-01-01T00:00:01Z",
         "2000-01-01T00:00:00Z",
@@ -88,8 +122,8 @@ TEST_CASE("Valid timestamps") {
     for (const auto& tc : test_cases) {
         const osmium::Timestamp t{tc};
         REQUIRE(tc == t.to_iso());
+        REQUIRE(tc == t.to_iso_all());
     }
-
 }
 
 TEST_CASE("Invalid timestamps") {
