@@ -1,12 +1,12 @@
 #include "catch.hpp"
 
+#include <osmium/util/delta.hpp>
+
 #include <cstdint>
 #include <vector>
 
-#include <osmium/util/delta.hpp>
-
 TEST_CASE("delta encode int") {
-    osmium::util::DeltaEncode<int> x;
+    osmium::DeltaEncode<int> x;
 
     REQUIRE(x.update(17) == 17);
     REQUIRE(x.value() == 17);
@@ -19,7 +19,7 @@ TEST_CASE("delta encode int") {
 }
 
 TEST_CASE("delta encode int with int32") {
-    osmium::util::DeltaEncode<int, int32_t> x;
+    osmium::DeltaEncode<int, int32_t> x;
 
     REQUIRE(x.update(17) == 17);
     REQUIRE(x.value() == 17);
@@ -32,7 +32,7 @@ TEST_CASE("delta encode int with int32") {
 }
 
 TEST_CASE("delta decode int") {
-    osmium::util::DeltaDecode<int> x;
+    osmium::DeltaDecode<int> x;
 
     REQUIRE(x.update(17) == 17);
     REQUIRE(x.update(10) == 27);
@@ -42,7 +42,7 @@ TEST_CASE("delta decode int") {
 }
 
 TEST_CASE("delta decode int with int32") {
-    osmium::util::DeltaDecode<int, int32_t> x;
+    osmium::DeltaDecode<int, int32_t> x;
 
     REQUIRE(x.update(17) == 17);
     REQUIRE(x.update(10) == 27);
@@ -52,7 +52,7 @@ TEST_CASE("delta decode int with int32") {
 }
 
 TEST_CASE("delta encode unsigned int") {
-    osmium::util::DeltaEncode<unsigned int> x;
+    osmium::DeltaEncode<unsigned int> x;
 
     REQUIRE(x.update(17) == 17);
     REQUIRE(x.update(10) == -7);
@@ -60,7 +60,7 @@ TEST_CASE("delta encode unsigned int") {
 }
 
 TEST_CASE("delta decode unsigned int") {
-    osmium::util::DeltaDecode<unsigned int> x;
+    osmium::DeltaDecode<unsigned int> x;
 
     REQUIRE(x.update(17) == 17);
     REQUIRE(x.update(10) == 27);
@@ -70,14 +70,16 @@ TEST_CASE("delta decode unsigned int") {
 TEST_CASE("delta encode and decode") {
     const std::vector<int> a = { 5, -9, 22, 13, 0, 23 };
 
-    osmium::util::DeltaEncode<int, int> de;
+    osmium::DeltaEncode<int, int> de;
     std::vector<int> b;
+    b.reserve(a.size());
     for (int x : a) {
         b.push_back(de.update(x));
     }
 
-    osmium::util::DeltaDecode<int, int> dd;
+    osmium::DeltaDecode<int, int> dd;
     std::vector<int> c;
+    c.reserve(b.size());
     for (int x : b) {
         c.push_back(dd.update(x));
     }
