@@ -273,7 +273,7 @@ TEST_CASE("Typed anonymous mapping: moving a memory mapping should work") {
     REQUIRE(!mapping1); // NOLINT(bugprone-use-after-move,misc-use-after-move) okay here, we are checking our own code
     mapping1.unmap(); // NOLINT(clang-analyzer-cplusplus.Move) okay here, we are checking our own code
 
-    const auto addr2 = mapping2.begin();
+    const auto* const addr2 = mapping2.begin();
     REQUIRE(*addr2 == 42);
 
     mapping2.unmap();
@@ -287,14 +287,14 @@ TEST_CASE("Typed anonymous mapping: move assignment should work") {
     REQUIRE(!!mapping1);
     REQUIRE(!!mapping2);
 
-    auto addr1 = mapping1.begin();
+    auto* const addr1 = mapping1.begin();
     *addr1 = 42;
 
     mapping2 = std::move(mapping1);
     REQUIRE(!!mapping2);
     REQUIRE(!mapping1); // NOLINT(bugprone-use-after-move,misc-use-after-move) okay here, we are checking our own code
 
-    const auto addr2 = mapping2.begin();
+    const auto* const addr2 = mapping2.begin();
     REQUIRE(*addr2 == 42);
 
     mapping2.unmap();
@@ -306,12 +306,12 @@ TEST_CASE("Typed anonymous mapping: remapping to larger size should work") {
     osmium::TypedMemoryMapping<uint32_t> mapping{1000};
     REQUIRE(mapping.size() >= 1000);
 
-    auto addr1 = mapping.begin();
+    auto* const addr1 = mapping.begin();
     *addr1 = 42;
 
     mapping.resize(8000);
 
-    const auto addr2 = mapping.begin();
+    const auto* const addr2 = mapping.begin();
     REQUIRE(*addr2 == 42);
 }
 
@@ -319,12 +319,12 @@ TEST_CASE("Typed anonymous mapping: remapping to smaller size should work") {
     osmium::TypedMemoryMapping<uint32_t> mapping{8000};
     REQUIRE(mapping.size() >= 8000);
 
-    auto addr1 = mapping.begin();
+    auto* const addr1 = mapping.begin();
     *addr1 = 42;
 
     mapping.resize(500);
 
-    const auto addr2 = mapping.begin();
+    const auto* const addr2 = mapping.begin();
     REQUIRE(*addr2 == 42);
 }
 #endif
